@@ -6,6 +6,7 @@ from typing import TYPE_CHECKING
 
 from tox.tox_env.python.runner import PythonRun
 
+from ._package_types import UvEditablePackage, UvPackage
 from ._venv import UvVenv
 
 if TYPE_CHECKING:
@@ -32,6 +33,10 @@ class UvVenvRunner(UvVenv, PythonRun):
             return "skip"
         return super().default_pkg_type
 
+    @property
+    def _package_types(self) -> tuple[str, ...]:
+        return *super()._package_types, UvPackage.KEY, UvEditablePackage.KEY
+
 
 __all__ = [
     "UvVenvRunner",
